fnss.topologies.parsers.parse_topology_zoo — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_topology_zoo

`parse_topology_zoo`(path)

  Parse a topology from the Topology Zoo dataset.

  Parameters : | path : str The path to the Topology Zoo file
  Returns : | topology : Topology or DirectedTopology The parsed topology.

  Notes

  If the parsed topology contains bundled links, i.e. multiple links between the same pair or nodes, the topology is parsed correctly but each bundle of links is represented as a single link whose capacity is the sum of the capacities of the links of the bundle (if capacity values were provided). The returned topology has a boolean attribute named link_bundling which is True if the topology contains at list one bundled link or False otherwise. If the topology contains bundled links, then each link has an additional boolean attribute named bundle which is True if that specific link was bundled in the original topology or False otherwise.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »